@@ -29,6 +29,8 @@
 #include <QProcess>
 #include <QDateTime>
 
+#include <QSessionManager>
+
 #include <jack/jack.h>
 
 #ifdef CONFIG_ALSA_SEQ
@@ -46,10 +48,14 @@ class qjackctlSessionForm;
 class qjackctlConnectionsForm;
 class qjackctlPatchbayForm;
 class qjackctlPatchbayRack;
-class qjackctlSystemTray;
 class qjackctlPortItem;
 
+#ifdef CONFIG_SYSTEM_TRAY
+class qjackctlSystemTray;
+#endif
+
 class QSocketNotifier;
+class QSessionManager;
 
 #ifdef CONFIG_DBUS
 class QDBusInterface;
@@ -99,9 +105,6 @@ public:
 	void queryDisconnect(
 		qjackctlPortItem *pOPort, qjackctlPortItem *pIPort, int iSocketType);
 
-	void setQuitForce(bool bQuitForce);
-	bool isQuitForce() const;
-
 	void updateMessagesFont();
 	void updateMessagesLimit();
 	void updateMessagesLogging();
@@ -116,8 +119,9 @@ public:
 	void updateTimeFormat();
 	void updateAliases();
 	void updateButtons();
+#ifdef CONFIG_SYSTEM_TRAY
 	void updateSystemTray();
-
+#endif
 	void showDirtySettingsWarning();
 	void showDirtySetupWarning();
 
@@ -125,9 +129,12 @@ public slots:
 
 	void startJack();
 	void stopJack();
+	void toggleJack();
 
 	void resetXrunStats();
 
+	void commitData(QSessionManager& sm);
+
 protected slots:
 
 	void readStdout();
@@ -166,7 +173,8 @@ protected slots:
 	void transportStop();
 	void transportForward();
 
-	void systemTrayContextMenu(const QPoint&);
+	void contextMenu(const QPoint&);
+
 	void activatePresetsMenu(QAction *);
 	void activatePreset(const QString&);
 	void activatePreset(int);
@@ -183,6 +191,8 @@ protected:
 	void appendStdoutBuffer(const QString&);
 	void flushStdoutBuffer();
 
+	bool stdoutBlock(int fd, bool bBlock) const;
+
 	QString formatExitStatus(int iExitStatus) const;
 
 	void shellExecute(const QString& sShellCommand,
@@ -273,6 +283,7 @@ private:
 	jack_client_t *m_pJackClient;
 	bool m_bJackDetach;
 	bool m_bJackShutdown;
+	bool m_bJackStopped;
 
 	snd_seq_t *m_pAlsaSeq;
 
@@ -320,14 +331,17 @@ private:
 
 	qjackctlPatchbayRack *m_pPatchbayRack;
 
-	qjackctlSystemTray *m_pSystemTray;
-
 	qjackctlPreset m_preset;
 
 	QString m_sStdoutBuffer;
 	QString m_sTimeDashes;
 	QString m_sJackCmdLine;
 
+#ifdef CONFIG_SYSTEM_TRAY
+	qjackctlSystemTray *m_pSystemTray;
+	bool m_bQuitClose;
+#endif
+
 	bool  m_bQuitForce;
 	float m_fSkipAccel;
 
