@@ -30,6 +30,9 @@
 #include <QTextStream>
 #include <QFileInfo>
 
+#ifdef CONFIG_JACK_VERSION
+#include <jack/jack.h>
+#endif
 
 #if defined(WIN32)
 #define DEFAULT_DRIVER "portaudio"
@@ -118,6 +121,7 @@ void qjackctlSetup::loadSetup (void)
 	bKeepOnTop               = m_settings.value("/KeepOnTop", false).toBool();
 	bSystemTray              = m_settings.value("/SystemTray", false).toBool();
 	bSystemTrayQueryClose    = m_settings.value("/SystemTrayQueryClose", true).toBool();
+	bStartMinimized          = m_settings.value("/StartMinimized", false).toBool();
 	bServerConfig            = m_settings.value("/ServerConfig", true).toBool();
 	sServerConfigName        = m_settings.value("/ServerConfigName", ".jackdrc").toString();
 	bServerConfigTemp        = m_settings.value("/ServerConfigTemp", false).toBool();
@@ -173,7 +177,7 @@ void qjackctlSetup::saveSetup (void)
 {
 	// Save all settings and options...
 	m_settings.beginGroup("/Program");
-	m_settings.setValue("/Version", QJACKCTL_VERSION);
+	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Presets");
@@ -230,6 +234,7 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/KeepOnTop",               bKeepOnTop);
 	m_settings.setValue("/SystemTray",              bSystemTray);
 	m_settings.setValue("/SystemTrayQueryClose",    bSystemTrayQueryClose);
+	m_settings.setValue("/StartMinimized",          bStartMinimized);
 	m_settings.setValue("/ServerConfig",            bServerConfig);
 	m_settings.setValue("/ServerConfigName",        sServerConfigName);
 	m_settings.setValue("/ServerConfigTemp",        bServerConfigTemp);
@@ -569,8 +574,16 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
-			out << QObject::tr("Qt: %1\n").arg(qVersion());
-			out << QObject::tr(QJACKCTL_TITLE ": %1\n").arg(QJACKCTL_VERSION);
+			out << QObject::tr("Qt: %1\n")
+				.arg(qVersion());
+			out << QObject::tr("%1: %2  (%3)\n")
+				.arg(QJACKCTL_TITLE)
+				.arg(CONFIG_BUILD_VERSION)
+				.arg(CONFIG_BUILD_DATE);
+		#ifdef CONFIG_JACK_VERSION
+			out << QObject::tr("JACK: %1\n")
+				.arg(jack_get_version_string());
+		#endif
 			return false;
 		}	// FIXME: Avoid auto-start jackd stuffed args!
 		else if (sArg != "-T" && sArg != "-ndefault") {
@@ -724,7 +737,7 @@ void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 		pWidget->adjustSize();
 		if (!bVisible)
 			bVisible = m_settings.value("/visible", false).toBool();
-		if (bVisible)
+		if (bVisible && !bStartMinimized)
 			pWidget->show();
 		else
 			pWidget->hide();
@@ -751,7 +764,7 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 		m_settings.setValue("/height", wsize.height());
 	#endif
 		if (!bVisible) bVisible = pWidget->isVisible();
-		m_settings.setValue("/visible", bVisible);
+		m_settings.setValue("/visible", bVisible && !bStartMinimized);
 		m_settings.endGroup();
 	}
 }
